@@ -16,7 +16,7 @@ import OFS.Traversable
 from zope.interface import implements
 from Products.PluggableAuthService.interfaces.authservice import IBasicUser
 
-metadata = None
+metadata = schema.MetaData()
 
 log = logging.getLogger(__name__)
 
@@ -54,7 +54,7 @@ class SurveyTreeItem(BaseObject):
     sorted tree.
     """
     __tablename__ = "tree"
-    __table_args__ = schema.UniqueConstraint("session_id", "path")
+    __table_args__ = (schema.UniqueConstraint("session_id", "path"), {})
 
     id = schema.Column(types.Integer(), primary_key=True, autoincrement=True)
     session_id = schema.Column(types.Integer(),
@@ -237,6 +237,23 @@ class Account(BaseObject):
 
 
 
+class AccountChangeRequest(BaseObject):
+    __tablename__ = "account_change"
+
+    id = schema.Column(types.String(16), primary_key=True, nullable=False)
+    account_id = schema.Column(types.Integer(),
+            schema.ForeignKey(Account.id, onupdate="CASCADE", ondelete="CASCADE"),
+            nullable=False, unique=True)
+    account = orm.relation(Account,
+            backref=orm.backref("change_request",
+                                uselist=False,
+                                cascade="all, delete, delete-orphan"))
+    value = schema.Column(types.String(255), nullable=False)
+    expires = schema.Column(types.DateTime(),
+            nullable=False)
+
+
+
 class SurveySession(BaseObject):
     """Information about a users session.
     """
@@ -363,7 +380,6 @@ class SurveySession(BaseObject):
 class Company(BaseObject):
     """Information about a company."""
     __tablename__ = "company"
-    __table_args__ = schema.UniqueConstraint("session_id", "path")
 
     id = schema.Column(types.Integer(), primary_key=True, autoincrement=True)
     session_id = schema.Column(types.Integer(),
@@ -442,13 +458,12 @@ class ActionPlan(BaseObject):
                                 cascade="all, delete, delete-orphan"))
 
 
+
 _instrumented = False
 if not _instrumented:
-    metadata=schema.MetaData()
-    metadata._decl_registry=dict()
-
+    metadata._decl_registry={}
     for cls in [ SurveyTreeItem, SurveySession, Module, Risk,
-                 ActionPlan, Account, Company ]:
+                 ActionPlan, Account, AccountChangeRequest, Company ]:
         declarative.instrument_declarative(cls, metadata._decl_registry, metadata)
     _instrumented = True
 
